# SpiegeLib

Synthesizer Programming with Intelligent Exploration, Generation, and Evaluation Library.

A library for research and development of work related to Automatic Sound Synthesizer Programming. Named after early electronic music pioneer Laurie Spiegel.

See full documention [here](https://spiegelib.github.io/spiegelib/).

Currently in development.
